@@ -3,7 +3,7 @@ package DBIx::OnlineDDL::Helper::SQLite;
 our $AUTHORITY = 'cpan:GSG';
 # ABSTRACT: Private OnlineDDL helper for SQLite-specific code
 use version;
-our $VERSION = 'v1.0.1'; # VERSION
+our $VERSION = 'v1.1.0'; # VERSION
 
 use v5.10;
 use Moo;
@@ -129,6 +129,9 @@ sub has_conflicting_triggers_on_table {
     });
 }
 
+# Always zero; multiple triggers per table/type aren't allowed
+sub has_triggers_on_table_to_be_copied { 0 }
+
 sub find_new_trigger_identifier {
     my ($self, $trigger_name) = @_;
 
@@ -152,6 +155,8 @@ sub analyze_table {
 
 # Keep Base->swap_tables (has transactional DDL)
 
+# Keep the trigger methods (not used)
+
 # Keep the other FK methods (not used)
 
 1;
@@ -168,7 +173,7 @@ DBIx::OnlineDDL::Helper::SQLite - Private OnlineDDL helper for SQLite-specific c
 
 =head1 VERSION
 
-version v1.0.1
+version v1.1.0
 
 =head1 DESCRIPTION
 
@@ -185,7 +190,7 @@ Grant Street Group <developers@grantstreet.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 - 2024 by Grant Street Group.
+This software is Copyright (c) 2018 - 2025 by Grant Street Group.
 
 This is free software, licensed under:
 
